apple_vision_recognize_text library
Classes
- AppleVisionRecognizeTextController
-
The AppleVisionRecognizeTextController holds all the logic of this plugin,
where as the
AppleVisionObjectclass is the frontend of this plugin. - RecognizedText
- RecognizeTextData
- RecognizeTextFunctions
- A class that converts the information from apple vision to dart
Enums
- Dispatch
- RecognitionLevel
- A value that determines whether the request prioritizes accuracy or speed in text recognition.